@@ -3,6 +3,8 @@ import control2020 as ct20
 import sympy as sp
 from typing import Union, Tuple, Dict
 import numpy as np
+import copy
+
 
 TF = Union[ct.TransferFunction, sp.Expr, float, str]
 
@@ -37,8 +39,8 @@ class System:
     def step_report(self, time: list = None) -> Dict[str, float]:
         return ct.step_info(self.full_system(), time)
 
-    def response_to(self, u: list, time: list = None) -> Tuple[np.float, np.float]:
-        t, y = ct.forced_response(self.full_system(), time, u)
+    def response_to(self, u: list, time: list) -> Tuple[list, list]:
+        t, y, _ = ct.forced_response(self.full_system(), T=time, U=u)
         return t, y
 
     def bode_open(self, omega: list = None) -> Tuple[np.float, np.float, np.float]:
@@ -46,7 +48,9 @@ class System:
         return mag, phase, omega
 
     def bode_close(self, omega: list = None) -> Tuple[list, list, list]:
-        mag, phase, omega_returned = ct.bode(self.full_system(), omega=omega, dB=True, deg=True, Plot=False)
+        mag, phase, omega_returned = ct.bode(self.full_system(), omega=omega, dB=True, Plot=False) # dB=True, deg=True,
+        phase = phase * 180. / np.pi
+        mag = 20. * np.log10(mag)
         return mag, phase, omega_returned
 
     def margins_open(self, omega: list = None) -> Tuple[float, float, float, float]:
@@ -64,3 +68,6 @@ class System:
             self.in_noise = normalized_tf(in_noise)
         if out_noise is not None:
             self.out_noise = normalized_tf(out_noise)
+
+    def copy(self):
+        return copy.deepcopy(self)
